### Create the data array from the existing dataset
setwd("C:/Users/y.kita/Dropbox (fukudalab-tokyotech)/夏の学校2019/ロジットモデル/分析結果　(北)")


rm(list = ls())
Data <- read.csv("all_tsukinigai_jitaku4.csv")
library(apollo)

########################################################################
######################### Apollo MNL Start ##############################
########################################################################

apollo_initialise()

database <- Data 


apollo_control = list(
  modelName  ="RS_NL_01",
  modelDescr ="MNL model",
  indivID    ="USER_ID")

apollo_beta=c(ASCwalk = 0,
              ASCbicycle = 0,
              ASCcar = 0,
              ASCbus = 0,
              ASCtrain = 0,
              bslopewalk = 0, 
              bslopebicycle = 0, 
              # bslopecar = 0, 
              bslopebus = 0, 
              bslopetrain = 0, 
              # btime = 0, 
              btimewalk = 0,
              btimebike = 0,
              btimebus = 0,
              btimetrain = 0,
              bfewalk = 0,
              bfebicycle = 0,
              bfecar = 0,
              bfebus = 0,
              bfetrain = 0,
              bcost = 0, 
              bdiswalk = 0, 
              bdisbicycle = 0, 
              bdiscar = 0, 
              bdisbus = 0, 
              bdistrain = 0)

apollo_fixed = c("ASCbicycle","bslopebicycle","bdisbicycle")

apollo_inputs=apollo_validateInputs()

apollo_probabilities=function(apollo_beta, apollo_inputs, functionality="estimate"){
  
  ### Attach inputs and detach after function exit
  apollo_attach(apollo_beta, apollo_inputs)
  on.exit(apollo_detach(apollo_beta, apollo_inputs))
  
  ### Create list of probabilities P
  P = list()
  
  ### Utility Function
  V = list()
  
  V[['walk']] = ASCwalk +
    (bslopewalk*slopemean+btimewalk)*timewalk/10+
    bdiswalk*distance/1000+bfewalk*(gender==2)
  
  V[['bicycle']] = ASCbicycle + 
    (bslopebicycle*slopemean+btimebike)*timebike/10 + 
    bdisbicycle*distance/1000+bfebicycle*(gender==2)
  
  V[['car']] = ASCcar + bdiscar*distance/1000+bfecar*(gender==2)
  
  V[['bus']] = ASCbus +
    (bslopebus*slopemean+btimebus)*timebike/10 +
    bcost*costbus/100+bdisbus*distance/1000+bfebus*(gender==2)
  
  V[['train']] = ASCtrain +
    (bslopetrain*slopemean+btimetrain)*timetrain/10 +
    bcost*costtrain/100+bdistrain*distance/1000+bfetrain*(gender==2)

  ### Logit Setting
  mnl_settings = list(
    alternatives = c(walk=420, bicycle=410, car=100, bus=240, train=200),
    avail = list(walk=alternativewalk, bicycle=alternativebike, car=alternativecar, bus=alternativebus, train=alternativetrain),
    choiceVar = travelmode,
    V = V
  )
  
  P[["model"]] = apollo_mnl(mnl_settings, functionality)
  
  ### Take product across observation for same individual
  P = apollo_panelProd(P, apollo_inputs, functionality)
  
  ### Prepare and return outputs of function
  P = apollo_prepareProb(P, apollo_inputs, functionality)
  return(P)
}

#### MODEL ESTIMATION
model = apollo_estimate(apollo_beta, apollo_fixed, apollo_probabilities, apollo_inputs)

# ################################################################# #
#### MODEL OUTPUTS                                               ####
# ################################################################# #
# ----------------------------------------------------------------- #
#---- FORMATTED OUTPUT (TO SCREEN)                               ----
# ----------------------------------------------------------------- #
apollo_modelOutput(model)

# ----------------------------------------------------------------- #
#---- FORMATTED OUTPUT (TO FILE, using model name)               ----
# ----------------------------------------------------------------- #
apollo_saveOutput(model)

########################################################################
######################### Apollo MNL End ################################
########################################################################

########################################################################
######################### Apollo MXL Start ########################
########################################################################

apollo_initialise()

database <- Data 


apollo_control = list(
  modelName  = "RS_MixOL_01",
  modelDescr = "Mixed Logit model",
  indivID    = "USER_ID",
  mixing     = TRUE,
  nCores     = 4)

apollo_beta=c(ASCwalk = 0,
              ASCbicycle = 0,
              ASCcar = 0,
              ASCbus = 0,
              ASCtrain = 0,
              bslopewalk = 0, 
              bslopebicycle = 0, 
              bslopecar = 0, 
              bslopebus = 0, 
              bslopetrain = 0, 
              btime = 0, 
              bfewalk = 0,
              bfebicycle = 0,
              bfebus = 0,
              bfetrain = 0,
              bcost = 0, 
              bdiswalk = 0, 
              bdisbicycle = 0, 
              bdiscar = 0, 
              bdisbus = 0, 
              bdistrain = 0)

apollo_fixed = c("ASCbicycle")

apollo_beta = apollo_readBeta(apollo_beta,
                              apollo_fixed,
                              "RS_NL_01",
                              overwriteFixed=TRUE)

# ################################################################# #
#### DEFINE RANDOM COMPONENTS                                    ####
# ################################################################# #

### Set parameters for generating draws
apollo_draws = list(
  interDrawsType = "halton",
  interNDraws    = 100,
  interUnifDraws = c(),
  interNormDraws = c("draws_wa","draws_bi","draws_ca","draws_bu","draws_tr"),
  intraDrawsType = "halton",
  intraNDraws    = 0,
  intraUnifDraws = c(),
  intraNormDraws = c()
)

### Create random parameters
apollo_randCoeff = function(apollo_beta, apollo_inputs){
  
  randcoeff = list()
  
  randcoeff[["betawalk"]] = bslopewalk + draws_wa
  randcoeff[["betabicycle"]] = bslopebicycle + draws_bi
  randcoeff[["betacar"]] = bslopecar + draws_bi
  randcoeff[["betabus"]] = bslopebus + draws_bi
  randcoeff[["betatrain"]] = bslopetrain + draws_bi
  
  return(randcoeff)
} 

# ################################################################# #
#### GROUP AND VALIDATE INPUTS                                   ####
# ################################################################# #

apollo_inputs=apollo_validateInputs()


apollo_probabilities=function(apollo_beta, apollo_inputs, functionality="estimate"){
  
  ### Attach inputs and detach after function exit
  apollo_attach(apollo_beta, apollo_inputs)
  on.exit(apollo_detach(apollo_beta, apollo_inputs))
  
  ### Create list of probabilities P
  P = list()
  
  ### Utility Function
  V = list()
  
  V[['walk']] = ASCwalk +
    (bslopewalk+(btime+bfewalk*(gender==2))*timewalk)*slopemean +
    bdiswalk*distance
  
  V[['bicycle']] = ASCbicycle +
    (betabicycle+(btime+bfebicycle*female)*Traveltime)*Slope_mean +
    bdisbicycle*Distance
  
  V[['car']] = ASCcar +
    betacar*Slope_mean +
    bdiscar*Distance
  
  V[['bus']] = ASCbus +
    (betabus+(btime+bfebus*female)*Traveltime)*Slope_mean +
    bdisbus*Distance
  
  V[['train']] = ASCtrain +
    (betatrain+(btime+bfetrain*female)*Traveltime)*Slope_mean +
    bdistrain*Distance
  
  ### Logit Setting
  mnl_settings = list(
    altertnatives = c(walk=420, bicycle=410, car=100, bus=240, train=200),
    avail = list(walk=alternativewalk, bicycle=alternativebycicle, car=alternativecar, bus=alternativebus, train=alternativetrain),
    choiceVar = travelmode,
    V = V
  )
  
  P[["model"]] = apollo_mnl(mnl_settings, functionality)
  
  ### Take product across observation for same individual
  P = apollo_panelProd(P, apollo_inputs, functionality)
  
  ### Prepare and return outputs of function
  P = apollo_prepareProb(P, apollo_inputs, functionality)
  return(P)
}

#### MODEL ESTIMATION
model = apollo_estimate(apollo_beta, apollo_fixed, apollo_probabilities, apollo_inputs)

# ################################################################# #
#### MODEL OUTPUTS                                               ####
# ################################################################# #
# ----------------------------------------------------------------- #
#---- FORMATTED OUTPUT (TO SCREEN)                               ----
# ----------------------------------------------------------------- #
apollo_modelOutput(model)

# ----------------------------------------------------------------- #
#---- FORMATTED OUTPUT (TO FILE, using model name)               ----
# ----------------------------------------------------------------- #
apollo_saveOutput(model)

########################################################################
######################### Apollo MXL End ################################
########################################################################